Class: Sevgi::Sundries::Grid::X Private
- Defined in:
- lib/sevgi/sundries/grid.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Horizontal grid axis.
Instance Attribute Summary
Attributes inherited from Axis
Attributes inherited from Ruler
Attributes inherited from Interval
Instance Method Summary collapse
-
#line ⇒ Sevgi::Geometry::Line
private
Returns the base horizontal line for this axis.
-
#line_at(y) ⇒ Sevgi::Geometry::Line
private
Returns a horizontal line translated to a y coordinate.
Methods inherited from Axis
Methods inherited from Ruler
#expand, #initialize, #margin, #ms, #sd, #sn, #su, #waste
Methods inherited from Interval
[], #[], #count, #d, #ds, #h, #hs, #initialize, #nds, #nhs
Constructor Details
This class inherits a constructor from Sevgi::Sundries::Grid::Axis
Instance Method Details
#line ⇒ Sevgi::Geometry::Line
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns the base horizontal line for this axis.
136 |
# File 'lib/sevgi/sundries/grid.rb', line 136 def line = @line ||= Geometry::Line[d, 0.0] |
#line_at(y) ⇒ Sevgi::Geometry::Line
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a horizontal line translated to a y coordinate.
141 |
# File 'lib/sevgi/sundries/grid.rb', line 141 def line_at(y) = line.at([0.0, y]) |