Class: Sevgi::Sundries::Grid::Y
- Defined in:
- lib/sevgi/sundries/grid.rb
Overview
Vertical grid axis.
Instance Attribute Summary
Attributes inherited from Axis
Attributes inherited from Ruler
Attributes inherited from Interval
Instance Method Summary collapse
-
#initialize(this, other) ⇒ void
constructor
Creates a vertical axis wrapper.
-
#line ⇒ Sevgi::Geometry::Line
Returns the base vertical line for this axis.
-
#line_at(x) ⇒ Sevgi::Geometry::Line
Returns a vertical line translated to an x coordinate.
Methods inherited from Ruler
#expand, #margin, #ms, #sd, #sn, #su, #waste
Methods inherited from Interval
[], #[], #count, #d, #ds, #h, #hs, #nds, #nhs
Constructor Details
#initialize(this, other) ⇒ void
Creates a vertical axis wrapper.
144 |
# File 'lib/sevgi/sundries/grid.rb', line 144 def initialize(this, other) = super(other, this) |
Instance Method Details
#line ⇒ Sevgi::Geometry::Line
Returns the base vertical line for this axis.
148 |
# File 'lib/sevgi/sundries/grid.rb', line 148 def line = @line ||= Geometry::Line[d, 90.0] |
#line_at(x) ⇒ Sevgi::Geometry::Line
Returns a vertical line translated to an x coordinate.
153 |
# File 'lib/sevgi/sundries/grid.rb', line 153 def line_at(x) = line.at([x, 0.0]) |