Class: Sevgi::Sundries::Grid::Y Private
- Defined in:
- lib/sevgi/sundries/grid.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Vertical grid axis.
Instance Attribute Summary
Attributes inherited from Axis
Attributes inherited from Ruler
Attributes inherited from Interval
Instance Method Summary collapse
-
#initialize(this, other) ⇒ void
constructor
private
Creates a vertical axis wrapper.
-
#line ⇒ Sevgi::Geometry::Line
private
Returns the base vertical line for this axis.
-
#line_at(x) ⇒ Sevgi::Geometry::Line
private
Returns a vertical line translated to an x coordinate.
Methods inherited from Ruler
#expand, #margin, #ms, #sd, #sn, #su, #waste
Methods inherited from Interval
[], #[], #count, #d, #ds, #h, #hs, #nds, #nhs
Constructor Details
#initialize(this, other) ⇒ void
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Creates a vertical axis wrapper.
151 |
# File 'lib/sevgi/sundries/grid.rb', line 151 def initialize(this, other) = super(other, this) |
Instance Method Details
#line ⇒ Sevgi::Geometry::Line
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns the base vertical line for this axis.
155 |
# File 'lib/sevgi/sundries/grid.rb', line 155 def line = @line ||= Geometry::Line[d, 90.0] |
#line_at(x) ⇒ Sevgi::Geometry::Line
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a vertical line translated to an x coordinate.
160 |
# File 'lib/sevgi/sundries/grid.rb', line 160 def line_at(x) = line.at([x, 0.0]) |